import { Fragment, jsx, jsxs } from "react/jsx-runtime";
import { useEditor, useValue } from "@tldraw/editor";
import { PORTRAIT_BREAKPOINT } from "../../constants.mjs";
import { useActions } from "../../context/actions.mjs";
import { useBreakpoint } from "../../context/breakpoints.mjs";
import {
  useAllowGroup,
  useAllowUngroup,
  useHasLinkShapeSelected,
  useThreeStackableItems,
  useUnlockedSelectedShapesCount
} from "../../hooks/menu-hooks.mjs";
import { TldrawUiMenuItem } from "../primitives/menus/TldrawUiMenuItem.mjs";
function DefaultActionsMenuContent() {
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(AlignMenuItems, {}),
    /* @__PURE__ */ jsx(DistributeMenuItems, {}),
    /* @__PURE__ */ jsx(StackMenuItems, {}),
    /* @__PURE__ */ jsx(ReorderMenuItems, {}),
    /* @__PURE__ */ jsx(ZoomOrRotateMenuItem, {}),
    /* @__PURE__ */ jsx(RotateCWMenuItem, {}),
    /* @__PURE__ */ jsx(EditLinkMenuItem, {}),
    /* @__PURE__ */ jsx(GroupOrUngroupMenuItem, {})
  ] });
}
function AlignMenuItems() {
  const actions = useActions();
  const twoSelected = useUnlockedSelectedShapesCount(2);
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["align-left"], disabled: !twoSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["align-center-horizontal"], disabled: !twoSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["align-right"], disabled: !twoSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["stretch-horizontal"], disabled: !twoSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["align-top"], disabled: !twoSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["align-center-vertical"], disabled: !twoSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["align-bottom"], disabled: !twoSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["stretch-vertical"], disabled: !twoSelected })
  ] });
}
function DistributeMenuItems() {
  const actions = useActions();
  const threeSelected = useUnlockedSelectedShapesCount(3);
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["distribute-horizontal"], disabled: !threeSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["distribute-vertical"], disabled: !threeSelected })
  ] });
}
function StackMenuItems() {
  const actions = useActions();
  const threeStackableItems = useThreeStackableItems();
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["stack-horizontal"], disabled: !threeStackableItems }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["stack-vertical"], disabled: !threeStackableItems })
  ] });
}
function ReorderMenuItems() {
  const actions = useActions();
  const oneSelected = useUnlockedSelectedShapesCount(1);
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["send-to-back"], disabled: !oneSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["send-backward"], disabled: !oneSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["bring-forward"], disabled: !oneSelected }),
    /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["bring-to-front"], disabled: !oneSelected })
  ] });
}
function ZoomOrRotateMenuItem() {
  const breakpoint = useBreakpoint();
  return breakpoint < PORTRAIT_BREAKPOINT.TABLET_SM ? /* @__PURE__ */ jsx(ZoomTo100MenuItem, {}) : /* @__PURE__ */ jsx(RotateCCWMenuItem, {});
}
function ZoomTo100MenuItem() {
  const actions = useActions();
  const editor = useEditor();
  const isZoomedTo100 = useValue("zoom is 1", () => editor.getZoomLevel() === 1, [editor]);
  return /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["zoom-to-100"], disabled: isZoomedTo100 });
}
function RotateCCWMenuItem() {
  const actions = useActions();
  const oneSelected = useUnlockedSelectedShapesCount(1);
  return /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["rotate-ccw"], disabled: !oneSelected });
}
function RotateCWMenuItem() {
  const actions = useActions();
  const oneSelected = useUnlockedSelectedShapesCount(1);
  return /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["rotate-cw"], disabled: !oneSelected });
}
function EditLinkMenuItem() {
  const actions = useActions();
  const showEditLink = useHasLinkShapeSelected();
  return /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["edit-link"], disabled: !showEditLink });
}
function GroupOrUngroupMenuItem() {
  const allowGroup = useAllowGroup();
  const allowUngroup = useAllowUngroup();
  return allowGroup ? /* @__PURE__ */ jsx(GroupMenuItem, {}) : allowUngroup ? /* @__PURE__ */ jsx(UngroupMenuItem, {}) : /* @__PURE__ */ jsx(GroupMenuItem, {});
}
function GroupMenuItem() {
  const actions = useActions();
  const twoSelected = useUnlockedSelectedShapesCount(2);
  return /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["group"], disabled: !twoSelected });
}
function UngroupMenuItem() {
  const actions = useActions();
  return /* @__PURE__ */ jsx(TldrawUiMenuItem, { ...actions["ungroup"] });
}
export {
  AlignMenuItems,
  DefaultActionsMenuContent,
  DistributeMenuItems,
  EditLinkMenuItem,
  GroupMenuItem,
  GroupOrUngroupMenuItem,
  ReorderMenuItems,
  RotateCCWMenuItem,
  RotateCWMenuItem,
  StackMenuItems,
  UngroupMenuItem,
  ZoomOrRotateMenuItem,
  ZoomTo100MenuItem
};
//# sourceMappingURL=DefaultActionsMenuContent.mjs.map
